@@ -56,9 +56,10 @@ sub init
 	my ( $w, $h) = $self-> size;
 	$self-> reset_days;
 
+	my $right_offset = $self-> font-> width * 9;
 	$self-> insert( ComboBox => 
 		origin   => [ 5, $h - $fh * 2 - 10 ],
-		size     => [ $w - 115, $fh + 4],
+		size     => [ $w - $right_offset - 15, $fh + 4],
 		name     => 'Month',
 		items    => $self-> make_months,
 		style    => cs::DropDownList,
@@ -68,15 +69,15 @@ sub init
 
 	$self-> insert( Label => 
 		origin => [ 5, $h - $fh - 4],
-		size   => [ $w - 115, $fh + 2],
+		size   => [ $w - $right_offset - 15, $fh + 2],
 		text   => '~Month',
 		focusLink => $self-> Month,
 		growMode => gm::GrowHiX | gm::GrowLoY,
 	);
 	
 	$self-> insert( SpinEdit => 
-		origin => [ $w - 105, $h - $fh * 2 - 10 ],
-		size   => [ 100, $fh + 4],
+		origin => [ $w - $right_offset - 5, $h - $fh * 2 - 10 ],
+		size   => [ $right_offset, $fh + 4],
 		name   => 'Year',
 		min    => 1900,
 		max    => 2099,
@@ -85,8 +86,8 @@ sub init
 	);
 
 	$self-> insert( Label => 
-		origin => [ $w - 105, $h - $fh - 4],
-		size   => [ 100, $fh + 2],
+		origin => [ $w - $right_offset - 5, $h - $fh - 4],
+		size   => [ $right_offset, $fh + 2],
 		text   => '~Year',
 		focusLink => $self-> Year,
 		growMode => gm::GrowLoX | gm::GrowLoY,
@@ -214,8 +215,9 @@ sub Day_Paint
 	$canvas-> color($c);
 	$canvas-> clipRect( 2, 2, $sz[0] - 3, $sz[1] - 3);
 	for ( $i = 0; $i < 7; $i++) {
+		my $tw = $canvas->get_text_width( $owner-> {days}-> [$i] );
 		$canvas-> text_out_bidi( $owner-> {days}-> [$i], 
-			$i * $zs[0] + $self-> {CX3}, $sz[1]-$zs[1]+$zs[3],
+			$i * $zs[0] + ($self->{X} - $tw)/2, $sz[1]-$zs[1]+$zs[3],
 		);
 	}
 
@@ -361,6 +363,7 @@ sub day_reset
 		$self-> get_text_width('28'),
 		$self-> get_text_width( $owner-> {days}-> [0])
 	);
+	$x3 += $x1/2;
 	$y = $self-> font-> height;
 	$self-> end_paint_info;
 	$self-> {X} = $x2 if $self-> {X} < $x2;
@@ -368,7 +371,6 @@ sub day_reset
 	$self-> {Y} = $y if $self-> {Y} < $y;
 	$self-> {CX1} = int(( $self-> {X} - $x1 ) / 2) + 4;
 	$self-> {CX2} = int(( $self-> {X} - $x2 ) / 2) + 4;
-	$self-> {CX3} = int(( $self-> {X} - $x3 ) / 2) + 4;
 	$self-> {CY} = int(( $self-> {Y} - $y ) / 2);
 }
 
@@ -476,15 +478,21 @@ Prima::Calendar - standard calendar widget
 
 =head1 SYNOPSIS
 
-	use Prima::Calendar;
+	use Prima qw(Calendar Application);
 	my $cal = Prima::Calendar-> create(
 		useLocale => 1,
+		size      => [ 150, 150 ],
 		onChange  => sub {
 			print $_[0]-> date_as_string, "\n";
 		},
 	);
 	$cal-> date_from_time( localtime );
 	$cal-> month( 5);
+	run Prima;
+
+=for podview <img src="calendar.gif" cut=1>
+
+=for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/calendar.gif">
 
 =head1 DESCRIPTION
 
