@@ -1,35 +1,10 @@
-#
-#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
-#  All rights reserved.
-#
-#  Redistribution and use in source and binary forms, with or without
-#  modification, are permitted provided that the following conditions
-#  are met:
-#  1. Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-#  2. Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-#  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-#  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-#  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-#  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-#  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-#  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-#  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#  SUCH DAMAGE.
-#
 #  Created by:
 #     Dmitry Karasik <dk@plab.ku.dk> 
 #     Anton Berezin  <tobez@plab.ku.dk>
-#
-#  $Id$
-#
+
 # edit block types
+use strict;
+use warnings;
 package 
     bt;
 use constant CUA          =>  0;
@@ -40,7 +15,6 @@ package Prima::Edit;
 use vars qw(@ISA);
 @ISA = qw(Prima::Widget Prima::MouseScroller Prima::GroupScroller Prima::UndoActions);
 
-use strict;
 use Prima::Const;
 use Prima::Classes;
 use Prima::ScrollBar;
@@ -1002,10 +976,10 @@ sub set_text_ref
 {
 	my ( $self, $ref) = @_;
 	return unless defined $ref;
-	$self-> {capLen} = length( $$ref);
+	$self-> {capLen} = length( $$ref) || 0;
 	$#{$self-> {lines}} = $self-> {capLen} / 40;
 	@{$self-> {lines}} = ();
-	@{$self-> {lines}} = split( "\n", $$ref);
+	@{$self-> {lines}} = split( "\n", $$ref // '');
 	$self-> {maxLine} = scalar @{$self-> {lines}} - 1;
 	$self-> reset_syntax;
 	$self-> reset_scrolls;
@@ -2776,8 +2750,6 @@ sub wordWrap        {($#_)?($_[0]-> set_word_wrap(    $_[1]))               :ret
 
 1;
 
-__DATA__
-
 =pod
 
 =head1 NAME
@@ -2786,12 +2758,16 @@ Prima::Edit - standard text editing widget
 
 =head1 SYNOPSIS
 
-	use Prima::Edit;
-	my $e = Prima::Edit-> create(
+	use Prima qw(Edit Application);
+	my $e = Prima::Edit->new(
 		text         => 'Hello $world',
 		syntaxHilite => 1,
 	);
-	$e-> selection( 1, 1, 1, 2);
+	run Prima;
+
+=for podview <img src="edit.gif" cut=1>
+
+=for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/edit.gif">
 
 =head1 DESCRIPTION
 
