@@ -455,20 +455,22 @@ sub sampleText       { ($#_)? shift-> {sampleText} = $_[1]  : return $_[0]-> {sa
 
 1;
 
-__DATA__
-
 =head1 NAME
 
 Prima::FontDialog - standard font dialog
 
 =head1 SYNOPSIS
 
-	use Prima::FontDialog;
+	use Prima qw(Application FontDialog);
 	my $f = Prima::FontDialog-> create;
 	return unless $f-> execute == mb::OK;
 	$f = $f-> logFont;
 	print "$_:$f->{$_}\n" for sort keys %$f;
 
+=for podview <img src="fontdlg.gif" cut=1>
+
+=for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/fontdlg.gif">
+
 =head1 DESCRIPTION
 
 The dialog provides selection of font by name, style, size, and encoding.
