@@ -245,8 +245,6 @@ sub import
 
 1;
 
-__DATA__
-
 
 =pod
 
@@ -270,6 +268,10 @@ dialog boxes.
 	$text = '(none)' unless defined $text;
 	Prima::MsgBox::message( "You have entered: '$text'", mb::Ok);
 
+=for podview <img src="msgbox.gif" cut=1>
+
+=for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/msgbox.gif">
+
 =head1 API
 
 =over
