@@ -62,6 +62,7 @@ sub state         {($#_)?$_[0]-> set_state ($_[1]):return $_[0]-> {pressState}}
 #  my ( $self, $increment) = @_;
 #}
 
+
 package Prima::SpinButton;
 use vars qw(@ISA);
 @ISA = qw(Prima::AbstractSpinButton);
@@ -70,8 +71,8 @@ sub profile_default
 {
 	return {
 		%{$_[ 0]-> SUPER::profile_default},
-		width        => 17,
-		height       => 24,
+		width        => 17 * $::application-> uiScaling,
+		height       => 24 * $::application-> uiScaling,
 	}
 }
 
@@ -203,13 +204,13 @@ sub on_paint
 
 	$canvas-> color( $clr[0]);
 	my $p1 = ( $p == 1) ? 1 : 0;
-	$canvas-> fillpoly([
+	$canvas-> fillpoly( [
 		$size[0] * 0.3 + $p1, $size[1] * 0.73 - $p1,
 		$size[0] * 0.5 + $p1, $size[1] * 0.87 - $p1,
 		$size[0] * 0.7 + $p1, $size[1] * 0.73 - $p1
 	]);
 	$p1 = ( $p == 2) ? 1 : 0;
-	$canvas-> fillpoly([
+	$canvas-> fillpoly( [
 		$size[0] * 0.3 + $p1, $size[1] * 0.27 - $p1,
 		$size[0] * 0.5 + $p1, $size[1] * 0.13 - $p1,
 		$size[0] * 0.7 + $p1, $size[1] * 0.27 - $p1
@@ -233,8 +234,8 @@ sub profile_default
 {
 	return {
 		%{$_[ 0]-> SUPER::profile_default},
-		width        => 18,
-		height       => 18,
+		width        => 18 * $::application-> uiScaling,
+		height       => 18 * $::application-> uiScaling,
 	}
 }
 
@@ -312,6 +313,18 @@ sub on_mouseleave
 	$self-> repaint if defined( delete $self->{prelight} );
 }
 
+sub fix_triangle
+{
+	my @spot = map { int($_ + .5) } @_;
+	my $d = $spot[4] - $spot[0];
+	if ($d % 2) {
+		$spot[2] = $spot[0] + ($d - 1) / 2;
+		$spot[4]--;
+	}
+	return \@spot;
+}
+
+
 sub on_paint
 {
 	my ( $self, $canvas) = @_;
@@ -365,17 +378,17 @@ sub on_paint
 
 	$canvas-> color( $clr[0]);
 	my $p1 = ( $p == 1) ? 1 : 0;
-	$canvas-> fillpoly([ 
+	$canvas-> fillpoly( fix_triangle( 
 		$size[0] * 0.2 + $p1, $size[1] * 0.65 - $p1,
 		$size[0] * 0.3 + $p1, $size[1] * 0.77 - $p1,
 		$size[0] * 0.4 + $p1, $size[1] * 0.65 - $p1
-	]);
+	));
 	$p1 = ( $p == 2) ? 1 : 0;
-	$canvas-> fillpoly([ 
-		$size[0] * 0.6 + $p1, $size[1] * 0.35 - $p1,
-		$size[0] * 0.7 + $p1, $size[1] * 0.27 - $p1,
-		$size[0] * 0.8 + $p1, $size[1] * 0.35 - $p1
-	]);
+	$canvas-> fillpoly( fix_triangle(
+		$size[0] * 0.59 + $p1, $size[1] * 0.35 - $p1,
+		$size[0] * 0.69 + $p1, $size[1] * 0.23 - $p1,
+		$size[0] * 0.79 + $p1, $size[1] * 0.35 - $p1
+	));
 }
 
 sub set_state
@@ -647,6 +660,9 @@ sub profile_default
 		value          => 0,
 		threshold      => 0,
 		vertical       => 0,
+		# additional properties for indeterminate mode
+		indeterminate	=> '1',
+		sliderLength	=> 30,
 	}
 }
 
@@ -659,6 +675,14 @@ sub init
 	$self-> {string} = '';
 	for (qw( vertical threshold min max relief indent value))
 	{$self-> $_($profile{$_}); }
+	
+	# additional properties for indeterminate mode
+	$self->{direction} = 1;
+	for (qw( indeterminate sliderLength))
+	{$self-> $_($profile{$_}); }
+	# If indeterminate is true, the start value must be > sliderLength
+	$self->value($self->{sliderLength}) if ($self->indeterminate);
+	
 	return %profile;
 }
 
@@ -672,6 +696,8 @@ sub on_paint
 {
 	my ($self,$canvas) = @_;
 	my ($x, $y) = $canvas-> size;
+	
+	$canvas->clear();
 	my $i = $self-> indent;
 	my ($clComplete,$clBack,$clFore,$clHilite) = ($self-> hiliteBackColor, $self-> backColor, $self-> color, $self-> hiliteColor);
 	my $v = $self-> {vertical};
@@ -680,9 +706,19 @@ sub on_paint
 	$complete = int(($complete - $i*2) * $self-> {value} / $range + 0.5);
 	my ( $l3, $d3) = ( $self-> light3DColor, $self-> dark3DColor);
 	$canvas-> color( $clComplete);
-	$canvas-> bar ( $v ? ($i, $i, $x-$i-1, $i+$complete) : ( $i, $i, $i + $complete, $y-$i-1));
+	
+	# INDETERMINATE STYLE HACK
+	my $left_bound = 
+		$self->indeterminate ? 
+			$complete - ($self->{sliderLength} * ($v ? $y : $x) / $range + 0.5) :
+			$i;
+	$canvas-> bar ( $v ? 
+		($i, $left_bound, $x-$i-1, $i+$complete) : 
+		($left_bound, $i, $i + $complete, $y-$i-1));
+	
 	$canvas-> color( $clBack);
 	$canvas-> bar ( $v ? ($i, $i+$complete+1, $x-$i-1, $y-$i-1) : ( $i+$complete+1, $i, $x-$i-1, $y-$i-1));
+
 	# draw the border
 	my $relief = $self-> relief;
 	$canvas-> color(( $relief == gr::Sink) ? $d3 : (( $relief == gr::Border) ? cl::Black : $l3));
@@ -696,7 +732,8 @@ sub on_paint
 	{
 		$canvas-> line( $j + 1, $j, $x - $j - 1, $j);
 		$canvas-> line( $x - $j - 1, $j, $x - $j - 1, $y - $j - 1);
-	}
+	}	
+	
 
 	# draw the text, if neccessary
 	my $s = $self-> {string};
@@ -741,25 +778,30 @@ sub set_bounds
 	$self-> value( $min) if $self-> {value} < $min;
 }
 
-sub value
-{
+sub value {
 	return $_[0]-> {value} unless $#_;
 	my $v = $_[1] < $_[0]-> {min} ? $_[0]-> {min} : ($_[1] > $_[0]-> {max} ? $_[0]-> {max} : $_[1]);
 	$v -= $_[0]-> {min};
-	my $old = $_[0]-> {value};
-	if (abs($old - $v) >= $_[0]-> {threshold}) {
-		my ($x, $y) = $_[0]-> size;
-		my $i = $_[0]-> {indent};
-		my $range = ( $_[0]-> {max} - $_[0]-> {min}) || 1;
-		my $x1 = $i + ($x - $i*2) * $old / $range;
-		my $x2 = $i + ($x - $i*2) * $v   / $range;
-		($x1, $x2) = ( $x2, $x1) if $x1 > $x2;
-		my $s = $_[0]-> {string};
+	if ($_[0]->indeterminate) {
 		$_[0]-> {value} = $v;
-		$_[0]-> notify(q(Stringify), $v, \$_[0]-> {string});
-		( $_[0]-> {string} eq $s) ?
-			$_[0]-> invalidate_rect( $x1, 0, $x2+1, $y) :
-			$_[0]-> repaint;
+		$_[0]-> repaint;
+	}
+	else {
+		my $old = $_[0]-> {value};
+		if (abs($old - $v) >= $_[0]-> {threshold}) {
+			my ($x, $y) = $_[0]-> size;
+			my $i = $_[0]-> {indent};
+			my $range = ( $_[0]-> {max} - $_[0]-> {min}) || 1;
+			my $x1 = $i + ($x - $i*2) * $old / $range;
+			my $x2 = $i + ($x - $i*2) * $v   / $range;
+			($x1, $x2) = ( $x2, $x1) if $x1 > $x2;
+			my $s = $_[0]-> {string};
+			$_[0]-> {value} = $v;
+			$_[0]-> notify(q(Stringify), $v, \$_[0]-> {string});
+			( $_[0]-> {string} eq $s) ?
+				$_[0]-> invalidate_rect( $x1, 0, $x2+1, $y) :
+				$_[0]-> repaint;
+		}
 	}
 }
 
@@ -777,6 +819,49 @@ sub min       {($#_)?$_[0]-> set_bounds($_[1], $_[0]-> {'max'})  : return $_[0]-
 sub max       {($#_)?$_[0]-> set_bounds($_[0]-> {'min'}, $_[1])  : return $_[0]-> {max};}
 sub threshold {($#_)?($_[0]-> {threshold} = $_[1]):return $_[0]-> {threshold};}
 
+sub indeterminate    {
+	my ($self, $indeterminate) = @_;
+	return $self-> {indeterminate} unless $#_;
+
+	# Create the timer for the motion in indeterminate mode
+	# if it is not still created
+	unless ( $self->{timer} ) {
+		$self->{timer} = $self->insert( Timer => 
+		name	    => 'Timer',
+		timeout     => 25,
+		delegations => ['Tick'],
+		);
+	}
+
+	# When the style property is changed, reset the timer frequency
+	# and the start_angle and for style circle the end_angle, too
+	if ( $indeterminate) {
+		$self->{timer}->start;
+	} 
+	
+	else {
+		$self->{timer}->stop;
+	}
+	$self->{indeterminate} = $indeterminate;
+	
+}
+
+sub Timer_Tick
+{
+	my $self = shift;
+	my $newval = $self->value;
+	my $sliderLength = $self->sliderLength;
+	$newval = $newval+1 if ($self->direction == 1);
+	$newval = $newval-1 if ($self->direction == 0);
+	$self->value($newval);
+	$self->direction(0) if ($newval == 100);
+	$self->direction(1) if ($newval == $sliderLength);
+	$self->repaint;
+}
+
+sub direction    {($#_)?($_[0]-> {direction} = $_[1])  :return $_[0]-> {direction};}
+sub sliderLength    {($#_)?($_[0]-> {sliderLength} = $_[1])  :return $_[0]-> {sliderLength};}
+
 # slider standard schemes
 package 
     ss;
@@ -1025,8 +1110,6 @@ package Prima::Slider;
 use vars qw(@ISA);
 @ISA = qw(Prima::AbstractSlider);
 
-use constant DefButtonX => 12;
-
 sub profile_default
 {
 	return {
@@ -1034,6 +1117,7 @@ sub profile_default
 		borderWidth    => 0,
 		ribbonStrip    => 0,
 		shaftBreadth   => 6,
+		knobBreadth    => 12,
 		tickAlign      => tka::Normal,
 		vertical       => 0,
 	}
@@ -1052,6 +1136,8 @@ sub profile_check_in
 	$p-> { autoWidth} = 0
 		if exists $p-> {width} || exists $p-> {size} || exists $p-> {rect} || 
 			( exists $p-> {left} && exists $p-> {right});
+	my $sc = $::application->uiScaling;
+	$p->{$_} = ( exists($p->{$_}) ? $p->{$_} : $default->{$_} ) * $sc for qw(shaftBreadth knobBreadth );
 	$self-> SUPER::profile_check_in( $p, $default);
 }
 
@@ -1059,10 +1145,10 @@ sub init
 {
 	my $self = shift;
 	$self-> {$_} = 0 
-		for qw( vertical tickAlign ribbonStrip shaftBreadth borderWidth);
+		for qw( vertical tickAlign ribbonStrip shaftBreadth borderWidth knobBreadth);
 	my %profile = $self-> SUPER::init( @_);
 	$self-> $_($profile{$_}) 
-		for qw( vertical tickAlign ribbonStrip shaftBreadth borderWidth);
+		for qw( vertical tickAlign ribbonStrip shaftBreadth borderWidth knobBreadth);
 	return %profile;
 }
 
@@ -1084,12 +1170,12 @@ sub on_paint
 		$sb, $v, 
 		$range, $min, 
 		$tval, $tlen, $ttxt, 
-		$ta
+		$ta, $kb
 	) = ( 
 		$self-> {shaftBreadth}, $self-> {vertical}, 
 		abs($self-> {max} - $self-> {min}) || 1, $self-> {min},
 		$self-> {tickVal}, $self-> {tickLen}, $self-> {tickTxt}, 
-		$self-> {tickAlign}
+		$self-> {tickAlign}, $self->{knobBreadth},
 	);
 	if ( $ta == tka::Normal) { 
 		$ta = 1; 
@@ -1108,9 +1194,9 @@ sub on_paint
 	if ( $v) {
 		my $bh = $canvas-> font-> height;
 		my $bw  = ( $size[0] - $sb) / 2;
-		return if $size[1] <= DefButtonX * ($self-> {readOnly} ? 1 : 0) + 2 * $bh + 2;
+		return if $size[1] <= $kb * ($self-> {readOnly} ? 1 : 0) + 2 * $bh + 2;
 
-		$canvas-> translate((( $ta == 1) ? 1 : -1) * ( $bw - $sb - DefButtonX), 0) 
+		$canvas-> translate((( $ta == 1) ? 1 : -1) * ( $bw - $sb - $kb), 0) 
 			if $ta < 3;
 		my $br  = $size[1] - 2 * $bh - 2;
 		$canvas-> rect3d( 
@@ -1155,11 +1241,11 @@ sub on_paint
 		}
 		unless ( $self-> {readOnly}) {
 			my @jp = (
-				$bw - 4,       $val - DefButtonX / 2,
-				$bw - 4,       $val + DefButtonX / 2,
-				$bw + $sb + 1, $val + DefButtonX / 2,
-				$bw + $sb + 8, $val,
-				$bw + $sb + 1, $val - DefButtonX / 2,
+				$bw - 4,       $val - $kb / 2,
+				$bw - 4,       $val + $kb / 2,
+				$bw + $sb + 1, $val + $kb / 2,
+				$bw + $sb * 2 + 2, $val,
+				$bw + $sb + 1, $val - $kb / 2,
 			);
 			$canvas-> color( $self->{prelight} ? $prelight : $clr[1]);
 			$canvas-> fillpoly( \@jp);
@@ -1171,12 +1257,13 @@ sub on_paint
 			$canvas-> line($bw - 3, $jp[7]-1, $jp[6]-1, $jp[7]-1);
 		}
 	} else {
-		my $bw = $canvas-> font-> width + $self-> {borderWidth};
+		my $mw = $canvas-> font-> width;
+		my $bw = $mw + $self-> {borderWidth};
 		my $bh  = ( $size[1] - $sb) / 2;
 		my $fh = $canvas-> font-> height;
-		return if $size[0] <= DefButtonX * ($self-> {readOnly} ? 1 : 0) + 2 * $bw + 2;
+		return if $size[0] <= $kb * ($self-> {readOnly} ? 1 : 0) + 2 * $bw + 2;
 
-		$canvas-> translate( 0, (( $ta == 1) ? -1 : 1) * ( $bh - $sb - DefButtonX)) 
+		$canvas-> translate( 0, (( $ta == 1) ? -1 : 1) * ( $bh - $sb - $kb)) 
 			if $ta < 3;
 		my $br  = $size[0] - 2 * $bw - 2;
 		$canvas-> rect3d( $bw, $bh, $bw + $br - 1, $bh + $sb - 1, 1, @c3d, $cht[1]), return 
@@ -1213,7 +1300,8 @@ sub on_paint
 			next if $x >= $size[0] or $val + $tw < 0;
 			push @texts, [
 				$$ttxt[$i], $val, $tw,
-				( $ta == 2) ? $bh - $$tlen[ $i] - 5 - $fh : $bh + $sb + $$tlen[ $i] + 5
+				( $ta == 2) ? $bh - $$tlen[ $i] - 5 - $fh : $bh + $sb + $$tlen[ $i] + 5,
+				$size[0]
 			];
 		}
 
@@ -1237,19 +1325,19 @@ sub on_paint
 				pop @texts;
 				goto NO_LABELS unless @texts;
 			} else {
-				my $dx = $texts[-1]->[1] - $rightmost_val;
 				$texts[-1]->[1] = $rightmost_val;
-				# push the label next to it (but not the 1st one)
-				$texts[-2]->[1] -= $dx if 2 < @texts;
+				my $lv = 2 * $rightmost_label_width + $mw;
+				$$_[-1] -= $lv for @texts[0..$#texts-1];
+				$texts[-1][-1] += $mw;
 			}
 
 			# draw labels
 			my $lastx = 0;
 			for ( @texts) {
-				my ( $text, $val, $width, $y) = @$_;
-				my $x = $val - $width;
-				next if $x < $lastx or $x < 0 or $val + $width >= $size[0];
-				$lastx = $val + $width;
+				my ( $text, $val, $half_width, $y, $xlim) = @$_;
+				my $x = $val - $half_width;
+				next if $x < $lastx or $x < 0 or $val + $half_width >= $xlim;
+				$lastx = $val + $half_width + $mw;
 				$canvas-> text_out_bidi( $text, $x, $y);
 			}
 		}
@@ -1257,11 +1345,11 @@ sub on_paint
 
 		unless ( $self-> {readOnly}) {
 			my @jp = (
-				$val - DefButtonX / 2, $bh - 2,
-				$val - DefButtonX / 2, $bh + $sb + 3,
-				$val + DefButtonX / 2, $bh + $sb + 3,
-				$val + DefButtonX / 2, $bh - 2,
-				$val,                  $bh - 9,
+				$val - $kb / 2, $bh - 2,
+				$val - $kb / 2, $bh + $sb + 3,
+				$val + $kb / 2, $bh + $sb + 3,
+				$val + $kb / 2, $bh - 2,
+				$val,           $bh - $sb - 1,
 			);
 			$canvas-> color( $self->{prelight} ? $prelight : $clr[1]);
 			$canvas-> fillpoly( \@jp);
@@ -1299,11 +1387,11 @@ sub update_geom_sizes
 			$maxtwid = $w if $maxtwid < $w;
 		}
 		$self->end_paint_info;
-		my $x = $maxtlen + $maxtwid * 2 + $self->shaftBreadth + $self->borderWidth + 5 + DefButtonX;
+		my $x = $maxtlen + $maxtwid * 2 + $self->shaftBreadth + $self->borderWidth + 5 + $self->knobBreadth;
 		$self->geomWidth($x);
 	} else {
 		return unless $self->autoHeight;
-		my $y = $maxtlen + $self->font->height * 2 + $self->shaftBreadth + $self->borderWidth + 5 + DefButtonX;
+		my $y = $maxtlen + $self->font->height * 2 + $self->shaftBreadth + $self->borderWidth + 5 + $self->knobBreadth;
 		$self->geomHeight($y);
 	}
 }
@@ -1327,7 +1415,7 @@ sub pos2info
 				abs($self-> {max} - $self-> {min}) / 
 				(( $size[1] - 2 * $bh - 5) || 1);
 
-		if ( $y < $val - DefButtonX / 2 or $y >= $val + DefButtonX / 2) {
+		if ( $y < $val - $self->knobBreadth / 2 or $y >= $val + $self->knobBreadth / 2) {
 			return 0, $ret1;
 		} else {
 			return 1, $ret1, $y - $val;
@@ -1346,7 +1434,7 @@ sub pos2info
 				abs($self-> {max} - $self-> {min}) / 
 				(( $size[0] - 2 * $bw - 5) || 1);
 
-		if ( $x < $val - DefButtonX / 2 or $x >= $val + DefButtonX / 2) {
+		if ( $x < $val - $self->knobBreadth / 2 or $x >= $val + $self->knobBreadth / 2) {
 			return 0, $ret1;
 		} else {
 			return 1, $ret1, $x - $val;
@@ -1509,12 +1597,12 @@ sub value
 			my $v2  = $bh + 1 + abs( $old - $self-> {min}) *
 				( $size[1] - 2 * $bh - 5) / (abs($self-> {max} - $self-> {min})||1);
 			( $v2, $v1) = ( $v1, $v2) if $v1 > $v2;
-			$v1 -= DefButtonX / 2;
-			$v2 += DefButtonX / 2 + 1;
+			$v1 -= $self->knobBreadth / 2;
+			$v2 += $self->knobBreadth / 2 + 1;
 			my $xd = 0;
 			$xd = (( $self-> {tickAlign} == tka::Normal) ? 1 : -1) *
-			( $bw - $sb - DefButtonX) if $self-> {tickAlign} != tka::Dual;
-			$self-> invalidate_rect( $bw - 4 + $xd, $v1, $bw + $sb + 9 + $xd, $v2);
+			( $bw - $sb - $self->knobBreadth) if $self-> {tickAlign} != tka::Dual;
+			$self-> invalidate_rect( $bw - 4 + $xd, $v1, $bw + $sb * 2 + 3 + $xd, $v2);
 		} else {
 			$sb = $size[1] / 6 unless $sb;
 			$sb = 2 unless $sb;
@@ -1525,12 +1613,12 @@ sub value
 			my $v2  = $bw + 1 + abs( $old - $self-> {min}) *
 				( $size[0] - 2 * $bw - 5) / (abs($self-> {max} - $self-> {min})||1);
 			( $v2, $v1) = ( $v1, $v2) if $v1 > $v2;
-			$v1 -= DefButtonX / 2;
-			$v2 += DefButtonX / 2 + 1;
+			$v1 -= $self->knobBreadth / 2;
+			$v2 += $self->knobBreadth / 2 + 1;
 			my $yd = 0;
 			$yd = (( $self-> {tickAlign} == tka::Normal) ? -1 : 1) *
-			( $bh - $sb - DefButtonX) if $self-> {tickAlign} != tka::Dual;
-			$self-> invalidate_rect( $v1, $bh - 9 + $yd, $v2, $bh + $sb + 4 + $yd);
+			( $bh - $sb - $self->knobBreadth) if $self-> {tickAlign} != tka::Dual;
+			$self-> invalidate_rect( $v1, $bh - 3 - $sb + $yd, $v2, $bh + $sb + 4 + $yd);
 		}
 		$self-> notify(q(Change)) unless $self-> {suppressNotify};
 	} else {
@@ -1542,6 +1630,17 @@ sub tickAlign   {($#_)?$_[0]-> set_tick_align  ($_[1]):return $_[0]-> {tickAlign
 sub ribbonStrip {($#_)?$_[0]-> set_ribbon_strip($_[1]):return $_[0]-> {ribbonStrip};}
 sub shaftBreadth{($#_)?$_[0]-> set_shaft_breadth($_[1]):return $_[0]-> {shaftBreadth};}
 
+sub knobBreadth
+{
+	return $_[0]->{knobBreadth} unless $#_;
+	my ( $self, $kb) = @_;
+	$kb = 1 if $kb < 1;
+	return if $kb == $self-> {knobBreadth};
+	$self-> {knobBreadth} = $kb;
+	$self-> update_geom_sizes;
+	$self-> repaint;
+}
+
 sub borderWidth
 {
 	return $_[0]-> {borderWidth} unless $#_;
@@ -1564,26 +1663,32 @@ my %RNT = (
 sub notification_types { return \%RNT; }
 }
 
-use constant DefButtonX => 10;
-
 sub profile_default
 {
 	return {
 		%{$_[ 0]-> SUPER::profile_default},
 		buttons        => 1,
 		stdPointer     => 0,
+		buttonWidth    => 10,
 	}
 }
 
+sub profile_check_in
+{
+	my ( $self, $p, $default) = @_;
+
+	my $sc = $::application->uiScaling;
+	$p->{$_} = ( exists($p->{$_}) ? $p->{$_} : $default->{$_} ) * $sc for qw(buttonWidth);
+	$self-> SUPER::profile_check_in( $p, $default);
+}
+
 sub init
 {
 	my $self = shift;
-	for ( qw( buttons pressState circX circY br butt1X butt1Y butt2X))
-		{$self-> {$_}=0}
+	$self-> {$_}=0 for qw( buttons pressState circX circY br butt1X butt1Y butt2X buttonWidth);
 	$self-> {string} = '';
 	my %profile = $self-> SUPER::init( @_);
-	for ( qw( buttons stdPointer))
-	{$self-> $_($profile{$_});}
+	$self-> $_($profile{$_}) for qw( buttons stdPointer buttonWidth);
 	$self-> reset;
 	return %profile;
 }
@@ -1611,10 +1716,10 @@ sub reset
 	$self-> {br}        = $br;
 	$self-> {circX}     = $size[0]/2;
 	$self-> {circY}     = ($size[1] + $fh) / 2;
-	$self-> {butt1X}    = $size[0] / 2 - $br * 0.4 - DefButtonX / 2;
+	$self-> {butt1X}    = $size[0] / 2 - $br * 0.4 - $self->buttonWidth / 2;
 	$self-> {butt1Y}    = ( $size[1] + $fh) / 2 - $br * 0.4;
-	$self-> {butt2X}    = $size[0] / 2 + $br * 0.4 - DefButtonX / 2;
-	$self-> {circAlive} = $br > DefButtonX * 5;
+	$self-> {butt2X}    = $size[0] / 2 + $br * 0.4 - $self->buttonWidth / 2;
+	$self-> {circAlive} = $br > $self->buttonWidth * 5;
 }
 
 sub offset2pt
@@ -1648,9 +1753,9 @@ sub on_paint
 	my @c3d  = ( $self-> dark3DColor, $self-> light3DColor);
 	my @cht  = ( $self-> hiliteColor, $self-> hiliteBackColor);
 	my @size = $canvas-> size;
-	my ( $range, $min, $tval, $tlen, $ttxt) =
+	my ( $range, $min, $tval, $tlen, $ttxt, $bw) =
 	( abs($self-> {max} - $self-> {min}), $self-> {min}, $self-> {tickVal},
-	$self-> {tickLen}, $self-> {tickTxt} );
+	$self-> {tickLen}, $self-> {tickTxt}, $self->{buttonWidth} );
 
 	if ( defined $self-> {singlePaint}) {
 		my @clip1 = @{$self-> {expectedClip}};
@@ -1667,66 +1772,63 @@ sub on_paint
 	my $br  = $self-> {br};
 	my $rad = $br * 0.3;
 	my @cpt = ( $self-> {circX}, $self-> {circY}, $rad*2+1, $rad*2+1);
-	if ( $self-> {circAlive}) {
-		if ( defined $self-> {singlePaint}) {
-			$canvas-> color( $prelight ) if $self->{prelight};
-			$canvas-> fill_ellipse( @cpt[0..1], $rad*2-5, $rad*2-5);
-			$canvas-> color( $clr[0]);
-		} else {
-			if ($self->{prelight}) {
-				$canvas-> color( $prelight );
-				$canvas-> fill_ellipse( @cpt[0..1], $rad*2-5, $rad*2-5);
-			}
-			$canvas-> color( $c3d[1]);
-			$canvas-> lineWidth(2);
-			$canvas-> arc( @cpt[0..1], $cpt[2]-2, $cpt[3]-2, 65, 235);
-			$canvas-> color( $c3d[0]);
-			$canvas-> arc( @cpt[0..1], $cpt[2]-2, $cpt[3]-2, 255, 405);
-			$canvas-> lineWidth(0);
-			$canvas-> color( $clr[0]);
-			$canvas-> ellipse( @cpt);
-		}
-
-		if ( $self-> {stdPointer}) {
-			my $dev = $range * 0.03;
-			my @j = (
-				$self-> offset2pt( @cpt[0,1], $self-> {value}, $rad * 0.8),
-				$self-> offset2pt( @cpt[0,1], $self-> {value} + $dev, $rad * 0.6),
-				$self-> offset2pt( @cpt[0,1], $self-> {value} - $dev, $rad * 0.6),
-			);
-			$self-> fillpoly( \@j);
-		} else {
-			my @cxt = ( $self-> offset2pt( @cpt[0,1], $self-> {value}, $rad - 10), 4, 4);
-			$canvas-> lineWidth(2);
-			$canvas-> color( $c3d[0]);
-			$canvas-> arc( @cxt[0..1], 3, 3, 65, 235);
-			$canvas-> color( $c3d[1]);
-			$canvas-> arc( @cxt[0..1], 3, 3, 255, 405);
-			$canvas-> lineWidth(0);
-			$canvas-> color( $clr[0]);
-		}
-
-		my $i;
-		unless ( defined $self-> {singlePaint}) {
-			for ( $i = 0; $i < scalar @{$tval}; $i++) {
-				my $r = $rad + 3 + $$tlen[ $i];
-				my ( $cos, $sin) = $self-> offset2data( $$tval[$i]);
-				$canvas-> line( $self-> offset2pt( @cpt[0,1], $$tval[$i], $rad + 3),
-					$cpt[0] + $r * $cos, $cpt[1] + $r * $sin
-				) if $$tlen[ $i];
-				$r += 3;
-				if ( defined $$ttxt[ $i]) {
-					my $y = $cpt[1] + $r * $sin - $fh / 2 * ( 1 - $sin);
-					my $x = $cpt[0] + $r * $cos - 
-						( 1 - $cos) * 
-						$canvas-> get_text_width( $$ttxt[ $i]) / 2;
-					$canvas-> text_out_bidi( $$ttxt[ $i], $x, $y);
-				}
-			}
-		}
-	} else {
-		$canvas-> bar( 0, 0, @size);
+	
+	if ( defined $self-> {singlePaint}) {
+		$canvas-> color( $prelight ) if $self->{prelight};
+		$canvas-> fill_ellipse( @cpt[0..1], $rad*2-5, $rad*2-5);
 		$canvas-> color( $clr[0]);
+	} else {
+		if ($self->{prelight}) {
+			$canvas-> color( $prelight );
+			$canvas-> fill_ellipse( @cpt[0..1], $rad*2-5, $rad*2-5);
+		}
+		$canvas-> color( $c3d[1]);
+		$canvas-> lineWidth(2);
+		$canvas-> arc( @cpt[0..1], $cpt[2]-2, $cpt[3]-2, 65, 235);
+		$canvas-> color( $c3d[0]);
+		$canvas-> arc( @cpt[0..1], $cpt[2]-2, $cpt[3]-2, 255, 405);
+		$canvas-> lineWidth(0);
+		$canvas-> color( $clr[0]);
+		$canvas-> ellipse( @cpt);
+	}
+
+	if ( $self-> {stdPointer}) {
+		my $dev = $range * 0.03;
+		my @j = (
+			$self-> offset2pt( @cpt[0,1], $self-> {value}, $rad * 0.8),
+			$self-> offset2pt( @cpt[0,1], $self-> {value} + $dev, $rad * 0.6),
+			$self-> offset2pt( @cpt[0,1], $self-> {value} - $dev, $rad * 0.6),
+		);
+		$self-> fillpoly( \@j);
+	} else {
+		my @cxt = ( $self-> offset2pt( @cpt[0,1], $self-> {value}, $rad - 10), 4, 4);
+		my $knob = $::application->uiScaling * 3;
+		$canvas-> lineWidth(2);
+		$canvas-> color( $c3d[0]);
+		$canvas-> arc( @cxt[0..1], $knob, $knob, 65, 235);
+		$canvas-> color( $c3d[1]);
+		$canvas-> arc( @cxt[0..1], $knob, $knob, 255, 405);
+		$canvas-> lineWidth(0);
+		$canvas-> color( $clr[0]);
+	}
+
+	if ( $self-> {circAlive} && !defined $self-> {singlePaint}) {
+		my $i;
+		for ( $i = 0; $i < scalar @{$tval}; $i++) {
+			my $r = $rad + 3 + $$tlen[ $i];
+			my ( $cos, $sin) = $self-> offset2data( $$tval[$i]);
+			$canvas-> line( $self-> offset2pt( @cpt[0,1], $$tval[$i], $rad + 3),
+				$cpt[0] + $r * $cos, $cpt[1] + $r * $sin
+			) if $$tlen[ $i];
+			$r += 3;
+			if ( defined $$ttxt[ $i]) {
+				my $y = $cpt[1] + $r * $sin - $fh / 2 * ( 1 - $sin);
+				my $x = $cpt[0] + $r * $cos - 
+					( 1 - $cos) * 
+					$canvas-> get_text_width( $$ttxt[ $i]) / 2;
+				$canvas-> text_out_bidi( $$ttxt[ $i], $x, $y);
+			}
+		}
 	}
 
 	my $ttw = $canvas-> get_text_width( $self-> {string});
@@ -1744,27 +1846,27 @@ sub on_paint
 		$at = 1, @cbd = reverse @cbd if $s & 1;
 		
 		$canvas-> rect3d( 
-			$self-> { butt1X}, $self-> { butt1Y}, $self-> { butt1X} + DefButtonX,
-			$self-> { butt1Y} + DefButtonX, 1, @cbd, $clr[1]
+			$self-> { butt1X}, $self-> { butt1Y}, $self-> { butt1X} + $bw,
+			$self-> { butt1Y} + $bw, 1, @cbd, $clr[1]
 		);
 		$canvas-> line( 
-			$self-> { butt1X} + 2 + $at, $self-> { butt1Y} + DefButtonX / 2 - $at,
-			$self-> { butt1X} - 2 + + DefButtonX + $at, $self-> {butt1Y} + DefButtonX / 2 - $at
+			$self-> { butt1X} + 2 + $at, $self-> { butt1Y} + $bw / 2 - $at,
+			$self-> { butt1X} - 2 + + $bw + $at, $self-> {butt1Y} + $bw / 2 - $at
 		);
 
 		@cbd = reverse @c3d; $at = 0;
 		$at = 1, @cbd = reverse @cbd if $s & 2;
 		$canvas-> rect3d( 
-			$self-> { butt2X}, $self-> { butt1Y}, $self-> { butt2X} + DefButtonX,
-			$self-> { butt1Y} + DefButtonX, 1, @cbd, $clr[1]
+			$self-> { butt2X}, $self-> { butt1Y}, $self-> { butt2X} + $bw,
+			$self-> { butt1Y} + $bw, 1, @cbd, $clr[1]
 		);
 		$canvas-> line( 
-			$self-> { butt2X} + 2 + $at, $self-> { butt1Y} + DefButtonX / 2 - $at,
-			$self-> { butt2X} - 2 + + DefButtonX + $at, $self-> {butt1Y} + DefButtonX / 2 - $at
+			$self-> { butt2X} + 2 + $at, $self-> { butt1Y} + $bw / 2 - $at,
+			$self-> { butt2X} - 2 + + $bw + $at, $self-> {butt1Y} + $bw / 2 - $at
 		);
 		$canvas-> line( 
-			$self-> { butt2X} + DefButtonX / 2 + $at, $self-> { butt1Y} + 2 - $at,
-			$self-> { butt2X} + DefButtonX / 2 + $at, $self-> { butt1Y} - 2 - $at + DefButtonX
+			$self-> { butt2X} + $bw / 2 + $at, $self-> { butt1Y} + 2 - $at,
+			$self-> { butt2X} + $bw / 2 + $at, $self-> { butt1Y} - 2 - $at + $bw
 		);
 	}
 
@@ -1819,8 +1921,8 @@ sub on_mousedown
 	return if $btn != mb::Left;
 	my @butt = ( 
 		$self-> {butt1X}, $self-> {butt1Y}, 
-		$self-> {butt2X}, $self-> {butt1X} + DefButtonX, 
-		$self-> {butt1Y} + DefButtonX, $self-> {butt2X} + DefButtonX
+		$self-> {butt2X}, $self-> {butt1X} + $self->buttonWidth, 
+		$self-> {butt1Y} + $self->buttonWidth, $self-> {butt2X} + $self->buttonWidth
 	);
 	if ( $self-> {buttons} and $y >= $butt[1] and $y < $butt[4]) {
 		if ( $x >= $butt[0] and $x < $butt[3]) {
@@ -1858,8 +1960,8 @@ sub on_mouseup
 	return unless $self-> {mouseTransaction};
 	my @butt = ( 
 		$self-> {butt1X}, $self-> {butt1Y}, $self-> {butt2X},
-		$self-> {butt1X} + DefButtonX, $self-> {butt1Y} + DefButtonX, 
-		$self-> {butt2X} + DefButtonX
+		$self-> {butt1X} + $self->buttonWidth, $self-> {butt1Y} + $self->buttonWidth, 
+		$self-> {butt2X} + $self->buttonWidth
 	);
 	$self-> scroll_timer_stop;
 	$self-> {pressState} = 0;
@@ -1991,6 +2093,16 @@ sub value
 	$self-> notify(q(Change)) unless $self-> {suppressNotify};
 }
 
+sub buttonWidth
+{
+	return $_[0]->{buttonWidth} unless $#_;
+	my ( $self, $bw) = @_;
+	$bw = 1 if $bw < 1;
+	return if $bw == $self-> {buttonWidth};
+	$self-> {buttonWidth} = $bw;
+	$self-> repaint;
+}
+
 1;
 
 =pod
