@@ -131,12 +131,7 @@ sub on_paint
 
 		$canvas->translate($x, $y);
 
-		my $stripes = $canvas->new_gradient( palette => [ $self->color, $self->backColor ] )->stripes(8+1);
-		my @colors;
-		for ( my $i = 0; $i < @$stripes; $i+=2 ) {
-			push @colors, $stripes->[$i] for 1 .. $stripes->[$i+1];
-		}
-
+		my @colors = $canvas->new_gradient( palette => [ $self->color, $self->backColor ] )->colors(8+1);
 		my $fill_spline = sub { 
 			my ( $n, $p ) = @_;
 			$canvas->color( $colors[( $self->{start_angle} + $n) % 8] );
@@ -267,6 +262,10 @@ Prima::Spinner - Show a spinner animation
 
   run Prima;
 
+=for podview <img src="spinner.gif" cut=1>
+
+=for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/spinner.gif">
+
 =head1 DESCRIPTION
 
 Prima::Spinner provides a simple spinning animation with two designs and the
