@@ -1,29 +1,3 @@
-#
-#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
-#  All rights reserved.
-#
-#  Redistribution and use in source and binary forms, with or without
-#  modification, are permitted provided that the following conditions
-#  are met:
-#  1. Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-#  2. Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-#  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-#  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-#  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-#  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-#  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-#  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-#  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#  SUCH DAMAGE.
-#
-#  $Id$
 =pod 
 
 =head1 NAME
@@ -37,13 +11,8 @@ Demonstration and test of mouse_event() function usage.
 =cut
 
 use strict;
-use Prima;
-use Prima::Classes;
-use Prima::Buttons;
-use Prima::MsgBox;
-use Prima::StdDlg;
-use Prima::Application;
-
+use warnings;
+use Prima qw(Buttons MsgBox StdDlg Application);
 
 my $state = 'empty';
 my $wtx   = 'Macros';
@@ -71,7 +40,7 @@ sub mopen
 		close F;
 		update();
 	} else {
-		MsgBox::message("Cannot load $f");
+		message("Cannot load $f");
 	}
 }
 
@@ -80,7 +49,7 @@ sub mopen
 sub msave
 {
 	unless ( scalar @data) {
-		MsgBox::message("Nothing to save");
+		message("Nothing to save");
 		return;
 	}
 	my $f = Prima::save_file(
@@ -96,7 +65,7 @@ sub msave
 		}
 		close F;
 	} else {
-		MsgBox::message("Cannot save $f");
+		message("Cannot save $f");
 	}
 }
 
@@ -104,6 +73,7 @@ sub msave
 my $w = Prima::MainWindow-> create(
 	text => $wtx,
 	size => [ 436, 54],
+	designScale => [ 7, 16 ],
 	menuItems => [[ '~File' => [
 			['~Open...' => 'F3' => 'F3' => \&mopen],
 			['~Save...' => 'F2' => 'F2' => \&msave],
