@@ -270,7 +270,7 @@ SV *
 Clipboard_get_handle( Handle self)
 {
 	char buf[ 256];
-	snprintf( buf, 256, "0x%08lx", apc_clipboard_get_handle( self));
+	snprintf( buf, 256, PR_HANDLE_FMT, apc_clipboard_get_handle( self));
 	return newSVpv( buf, 0);
 }
 
